@@ -191,7 +191,8 @@ l_CV<-function(data,y,x,lambda,k,mode=2,binary=FALSE,step=1000,bound=0.5,fista=T
       else{
         if(fista){
           coeff<-lasso_fista(train_data,y,x,lambda,max_step=step,image=FALSE)[[1]]
-        }else{coeff<-lasso_ista(train_data,y,x,lambda,max_step=step,image=FALSE)[[1]]}
+        }else{coeff<-lasso_ista(train_data,y,x,lambda,max_step=step,image=FALSE)[[1]]
+        }
       }
     }
 
@@ -209,6 +210,7 @@ l_CV<-function(data,y,x,lambda,k,mode=2,binary=FALSE,step=1000,bound=0.5,fista=T
     else{
       y_pred<-apply(coeff,2,function(x)variable_value%*%x)
       #Each column is the predicted value for lambda i
+      #print(y_pred) NA
       PE<-apply(y_pred,2,function(x)sqrt(crossprod(test_value-x,test_value-x)/nrow(y_pred)))#MSE in each fold
     }
     MSE[i,]<-(PE)
@@ -352,13 +354,13 @@ lasso_fista <- function(data, y, x, lambda, max_step = 10000, type = "Gaussian",
 
   D <- cbind(intercept = 1, X)
   DD <- crossprod(D, D)
-  h <- matrix(ini, nrow = ncol(D), ncol = 1) # valores iniciales
   L <- max(eigen(DD)$values) # Lipschitz constant
   race <- 1 / (L)
 
   if (type == "Gaussian") {
     for (i in 1:length(lambda)) {
       alpha <- lambda[i]
+      h <- matrix(ini, nrow = ncol(D), ncol = 1) # valores iniciales
       z <- h# valor inicial 2
       t_old <- 1
       for (k in 1:max_step) {
@@ -389,6 +391,7 @@ lasso_fista <- function(data, y, x, lambda, max_step = 10000, type = "Gaussian",
   if (type == "Binomial") {
     for (i in 1:length(lambda)) {
       alpha <- lambda[i]
+      h <- matrix(ini, nrow = ncol(D), ncol = 1)
       h_old <- h
       z <- h
       t_old <- 1
